==> jasperreports_3.7.0+dfsg.orig.tar.gz: jasperreports-3.7.0.orig/src/net/sf/jasperreports/charts/xml/JRPieDatasetFactory.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.charts.xml;

import net.sf.jasperreports.charts.design.JRDesignPieDataset;
import net.sf.jasperreports.engine.JRChart;
import net.sf.jasperreports.engine.xml.JRBaseFactory;

import org.xml.sax.Attributes;


/**
 * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
 * @version $Id: JRPieDatasetFactory.java 3032 2009-08-27 11:32:28Z teodord $
 */
public class JRPieDatasetFactory extends JRBaseFactory
{
	private static final String ATTRIBUTE_minPercentage = "minPercentage";
	private static final String ATTRIBUTE_maxCount = "maxCount";
	
	/**
	 *
	 */
	public Object createObject(Attributes attrs)
	{
		JRChart chart = (JRChart) digester.peek();
		JRDesignPieDataset dataset = (JRDesignPieDataset)chart.getDataset();

		String minPercentage = attrs.getValue(ATTRIBUTE_minPercentage);
		if(minPercentage != null && minPercentage.length() > 0)
		{
			dataset.setMinPercentage(new Float(minPercentage));
		}
		
		String maxCount = attrs.getValue(ATTRIBUTE_maxCount);
		if(maxCount != null && maxCount.length() > 0)
		{
			dataset.setMaxCount(new Integer(maxCount));
		}
		
		return dataset;
	}

}

==> jasperreports3.7_3.7.4+dfsg.orig.tar.gz: jasperreports3.7-3.7.4.orig/src/net/sf/jasperreports/charts/xml/JRPieDatasetFactory.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.charts.xml;

import net.sf.jasperreports.charts.design.JRDesignPieDataset;
import net.sf.jasperreports.engine.JRChart;
import net.sf.jasperreports.engine.xml.JRBaseFactory;

import org.xml.sax.Attributes;


/**
 * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
 * @version $Id: JRPieDatasetFactory.java 3676 2010-04-02 09:35:07Z shertage $
 */
public class JRPieDatasetFactory extends JRBaseFactory
{
	private static final String ATTRIBUTE_minPercentage = "minPercentage";
	private static final String ATTRIBUTE_maxCount = "maxCount";
	
	/**
	 *
	 */
	public Object createObject(Attributes attrs)
	{
		JRChart chart = (JRChart) digester.peek();
		JRDesignPieDataset dataset = (JRDesignPieDataset)chart.getDataset();

		String minPercentage = attrs.getValue(ATTRIBUTE_minPercentage);
		if(minPercentage != null && minPercentage.length() > 0)
		{
			dataset.setMinPercentage(Float.valueOf(minPercentage));
		}
		
		String maxCount = attrs.getValue(ATTRIBUTE_maxCount);
		if(maxCount != null && maxCount.length() > 0)
		{
			dataset.setMaxCount(Integer.valueOf(maxCount));
		}
		
		return dataset;
	}

}
